
%% Linearized Vehicle Model

%constants 
v = 1.93;
beta = -42.40*pi/180;
r = 67.34*pi/180;

l_front = 0.30;                 % length from CG to front axle [m]
l_rear  = 0.26;                 % length from CG to rear axle [m]
l_tread = 0.38;                 % wheel tread [m]
A_front = 0.0285;               % vehicle front and side area [m^2]
m = 7.0;                        % vehicle mass [kg]
I = 0.4535;                     % moment of inertia around vehicle z-axis [kg*m^2]
c_air = 1.07;                   % air resistance coefficient
rho_air = 1.2928;               % air density (kg/m^3)

c_fl = 12/2;
c_fr = 12/2;
c_rl = 12/2;
c_rr = 12/2;

% each wheel only has half the torque from the motor
F_lrl = 11.71/2;
F_lrr = 11.71/2;

delta = -29.47*pi/180;

% always zero when rwd
F_lfl = 0;
F_lfr = 0;

%dV_dot / dV
A1 = 1/m       *( -c_air*A_front*rho_air*v*cos(beta) ...
                  - l_front*r*(c_fl + c_fr)*sin(delta - beta)/v^2 ...
                  - (c_rl + c_rr)*l_rear*r*sin(beta)/v^2 );
%dV_dot / dBeta              
A2 = 1/m       *( (F_lfl + F_lfr + c_fl + c_fr)*sin(delta - beta) ...
                  - (c_rl + c_rr + F_lrl + F_lrr - 0.5*c_air*A_front*rho_air*v^2)*sin(beta) ...
                  + (c_fl + c_fr)*(delta - beta - l_rear*r/v)*cos(delta - beta) ...
                  + (c_rl + c_rr)*(-beta + l_rear*r/v)*cos(beta));
%dV_dot / dr              
A3 = 1/(m*v)   *( l_front*sin(delta - beta)*(c_fl + c_fr) ...
                  + l_rear*sin(beta)*(c_rl + c_rr) ) ;
%dBeta_dot / dV              
A4 = -1/(m*v^2)*( (c_fl + c_fr)*(delta - beta - 2*l_front*r/v)*cos(delta - beta) ...
                  + (F_lfl + F_lfr)*sin(delta - beta) ...
                  - (F_lrl + F_lrr + 0.5*c_air*A_front*rho_air*v^2)*sin(beta) ...
                  + (c_rl+c_rr)*(-beta + 2*l_rear*r/v)*cos(beta));
%dBeta_dot / dBeta 
A5 = 1/(m*v)   *( (c_fl + c_fr)*(delta - beta - l_front*r/v)*sin(delta - beta) ...
                  - (c_fl + c_fr + F_lfl + F_lfr)*cos(delta - beta) ...
                  - (c_rl + c_rr)*(-beta + l_rear*r/v)*sin(beta) ...
                  - (c_rl + c_rr + F_lrl + F_lrr - 0.5*c_air*A_front*rho_air*v^2)*cos(beta));
%dBeta_dot / dr
A6 = 1/(m*v^2) *( l_rear*(c_rl + c_rr)*cos(beta) ...
                  - l_front*(c_fl + c_fr)*cos(delta - beta)) - 1;
%dr_dot / dV
A7 = 1/(I*v^2) *( l_front^2*r*(c_fl+c_fr)*cos(delta) ...
                  + 0.5*l_front*r*l_tread*(c_fl - c_fr)*sin(delta) ...
                  + l_rear^2*r*(c_rl + c_rr));
%dr_dot / dBeta
A8 = 1/I       *( -l_front*(c_fl + c_fr)*cos(delta) ...
                  - 0.5*l_tread*(c_fl - c_fr)*sin(delta) + l_rear*(c_rl + c_rr));
%dr_dot / dr            
A9 = 1/(I*v)   *( -l_front^2*(c_fl + c_fr)*cos(delta) ...
                  - 0.5*l_front*l_tread*(c_fl - c_fr)*sin(delta) - l_rear^2*(c_rl + c_rr));

%dV_dot / dF_L
B1 = cos(beta)/m;

%dV_dot / dDelta
B2 = -1/m      *( (F_lfl+ F_lfr + c_fl + c_fr)*sin(delta - beta) ...
                  + (c_fl + c_fr)*(delta - beta - l_front*r/v)*cos(delta - beta));
              
%dBeta_dot / dF_L          
B3 = -sin(beta)/(m*v);

%dBeta_dot / dDelta
B4 = 1/(m*v)   *( (c_fl + c_fr + F_lfl + F_lfr)*cos(delta - beta) ...
                  - (c_fl + c_fr)*(delta - beta - l_front*r/v)*sin(delta - beta));
              
%dr_dot / dF_L
B5 = 0;

%dr_dot / dDelta
B6 = 1/I       *( l_front*(c_fl + c_fr)*cos(delta) ...
                  - ( l_front*(c_fl + c_fr)*(delta - beta - l_front*r/v) + l_tread*(F_lfr - F_lfl)/2 )*sin(delta) ...
                  + l_tread*(c_fl - c_fr)*sin(delta)/2 ...
                  + ( l_tread*(c_fl - c_fr)*(delta - beta - l_front*r/v)/2 + l_front*(F_lfr + F_lfl) )*cos(delta) ...
                  - l_rear*(c_rl + c_rr));


A = [A1 A2 A3;
     A4 A5 A6;
     A7 A8 A9];
 
B = [B1 B2;
     B3 B4;
     B5 B6];
 
C = eye(3);

D = 0;

sys = ss(A,B,C,D);

[T, eigenvalues] = eig(A);

diag_canonical = T\A*T;

controllability = ctrb(A,B)
rank_ctrb = rank(ctrb(A,B))

