
%% Show simulation movie
fig1 = figure();

% time interval between movie frames
step = 0.1;

% find indices to include in movie
next = 0;
index = [];
for i = 1:length(simout_time)
    if simout_time(i) >= next;
       index = [index i];
       next = next+step;
    end
end

% plot frames
frame = 0;
xpos = 0;
lastxpos = 0;
for now = index
    
    % rotation matrix for car
    R_car = [cos(simout_psi(now)) -sin(simout_psi(now)) ;
             sin(simout_psi(now))  cos(simout_psi(now))]';

    % rotation matrix for front wheels
    R_steering = [cos(simout_delta(now)) -sin(simout_delta(now)) ;
                  sin(simout_delta(now))  cos(simout_delta(now))]';
         
    % create car and wheels
    car         = R_car*[l_front  l_front  -l_rear  -l_rear  l_front ; l_tread/2 -l_tread/2 -l_tread/2 l_tread/2 l_tread/2];
    rear_wheel  = R_car*[r_wheel r_wheel -r_wheel -r_wheel r_wheel; w_wheel/2 -w_wheel/2 -w_wheel/2 w_wheel/2 w_wheel/2];    
    front_wheel = R_steering*rear_wheel;

    % find car and wheel positions
    carpos = simout_position.signals.values(now,:);        
    front_left_pos  = R_car*[l_front l_tread/2]';
    front_right_pos = R_car*[l_front -l_tread/2]';
    rear_right_pos  = R_car*[-l_rear -l_tread/2]';
    rear_left_pos  = R_car*[-l_rear l_tread/2]';
        
    % plot trajectory
    hold off
    plot(-simout_position.signals.values(1:now,2), simout_position.signals.values(1:now,1), 'r');
    hold on
    % plot waypoints
    plot(-waypoints(2:5:length(waypoints)),waypoints(1:5:length(waypoints)), '-ob');
    
    % set axes to follow car
    if (carpos(1) - xpos >= 4)
        xpos = xpos + (carpos(1) - lastxpos);
    end
    if (carpos(1) - xpos <= -4)
        xpos = xpos - (lastxpos - carpos(1));
    end      
    axis([-carpos(2)-5 -carpos(2)+5 xpos-5 xpos+5])
    lastxpos = carpos(1);
    
    % plot car
    plot(-carpos(2)+car(2,:), carpos(1)+car(1,:),'g')                                                           % vehicle body
    patch(-carpos(2)+front_right_pos(2)+front_wheel(2,:), carpos(1)+front_right_pos(1)+front_wheel(1,:),'r');   % front right wheel
    patch(-carpos(2)+rear_right_pos(2)+rear_wheel(2,:), carpos(1)+rear_right_pos(1)+rear_wheel(1,:),'b');       % rear right wheel
    patch(-carpos(2)+rear_left_pos(2)+rear_wheel(2,:), carpos(1)+rear_left_pos(1)+rear_wheel(1,:),'b');         % rear left wheel
    patch(-carpos(2)+front_left_pos(2)+front_wheel(2,:), carpos(1)+front_left_pos(1)+front_wheel(1,:),'r');     % front left wheel
    
    % store frame
    frame = frame + 1;
    car_movie(frame) = getframe;
    
    % enable to pause movie between frames
    %pause(.05);
end
    
    